@@ -35,6 +35,7 @@ from ...workingtree import WorkingTree
 from .. import (
     tests,
     )
+from ...tests.script import TestCaseWithTransportAndScript
 from ...tests.features import PluginLoadedFeature
 
 
@@ -196,15 +197,29 @@ class TestGitBlackBox(ExternalBase):
         tree.add(['a'])
         output, error = self.run_bzr(['diff', '--format=git'], retcode=1)
         self.assertEqual(error, '')
-        self.assertEqual(output,
-                         'diff --git /dev/null b/a\n'
-                         'old mode 0\n'
-                         'new mode 100644\n'
-                         'index 0000000..c197bd8 100644\n'
-                         '--- /dev/null\n'
-                         '+++ b/a\n'
-                         '@@ -0,0 +1 @@\n'
-                         '+contents of a\n')
+        # Some older versions of Dulwich (< 0.19.12) formatted diffs slightly
+        # differently.
+        from dulwich import __version__ as dulwich_version
+        if dulwich_version < (0, 19, 12):
+            self.assertEqual(output,
+                             'diff --git /dev/null b/a\n'
+                             'old mode 0\n'
+                             'new mode 100644\n'
+                             'index 0000000..c197bd8 100644\n'
+                             '--- /dev/null\n'
+                             '+++ b/a\n'
+                             '@@ -0,0 +1 @@\n'
+                             '+contents of a\n')
+        else:
+            self.assertEqual(output,
+                             'diff --git a/a b/a\n'
+                             'old file mode 0\n'
+                             'new file mode 100644\n'
+                             'index 0000000..c197bd8 100644\n'
+                             '--- /dev/null\n'
+                             '+++ b/a\n'
+                             '@@ -0,0 +1 @@\n'
+                             '+contents of a\n')
 
     def test_git_import_uncolocated(self):
         r = GitRepo.init("a", mkdir=True)
@@ -393,6 +408,30 @@ class SwitchTests(ExternalBase):
                 self.assertEqual([], list(tree.iter_changes(basis_tree)))
 
 
+class SwitchScriptTests(TestCaseWithTransportAndScript):
+
+    def test_switch_preserves(self):
+        # See https://bugs.launchpad.net/brz/+bug/1820606
+        self.run_script("""
+$ brz init --git r
+Created a standalone tree (format: git)
+$ cd r
+$ echo original > file.txt
+$ brz add
+adding file.txt
+$ brz ci -q -m "Initial"
+$ echo "entered on master branch" > file.txt
+$ brz stat
+modified:
+  file.txt
+$ brz switch -b other
+2>Tree is up to date at revision 1.
+2>Switched to branch other
+$ cat file.txt
+entered on master branch
+""")
+
+
 class GrepTests(ExternalBase):
 
     def test_simple_grep(self):
